@@ -9,6 +9,7 @@ mod duplicates;
 mod files;
 mod hashing;
 mod model;
+mod reporter;
 
 fn main() {
     pretty_env_logger::init();
@@ -16,10 +17,7 @@ fn main() {
     debug!("The command line arguments provided are {:?}.", arguments);
 
     let raw_files = crate::files::get_files_in_current_directory();
-    let files = crate::model::to_file_content(raw_files);
-    let duplicates = crate::duplicates::get_all_duplicates(files);
-
-    for duplicate in duplicates {
-        println!("{:?}", duplicate);
-    }
+    let (hashed_files, filename_to_line_number_to_line) = crate::model::to_file_content(raw_files);
+    let duplicates = crate::duplicates::get_all_duplicates(hashed_files);
+    crate::reporter::pretty_print_duplicates(filename_to_line_number_to_line, duplicates);
 }
